kicad-developers team mailing list archive
-
kicad-developers team
-
Mailing list archive
-
Message #33923
Re: [PATCH] Pcbnew menu bar
-
To:
<kicad-developers@xxxxxxxxxxxxxxxxxxx>
-
From:
Maciej Sumiński <maciej.suminski@xxxxxxx>
-
Date:
Wed, 14 Feb 2018 09:54:42 +0100
-
Authentication-results:
spf=pass (sender IP is 188.184.36.46) smtp.mailfrom=cern.ch; lists.launchpad.net; dkim=none (message not signed) header.d=none;lists.launchpad.net; dmarc=bestguesspass action=none header.from=cern.ch;
-
In-reply-to:
<CF9C0EC6-4681-449C-8CE8-81ADEA1CA2D4@rokeby.ie>
-
Spamdiagnosticmetadata:
NSPM
-
Spamdiagnosticoutput:
1:99
-
User-agent:
Mozilla/5.0 (X11; Linux x86_64; rv:52.0) Gecko/20100101 Thunderbird/52.5.2
Well done, Michael! There is one more patch that should go with these
changes (see the attachment), otherwise Linux users see some asserts.
I mostly agree with Jeff's remarks below, but IMHO your patches are
already a huge improvement in their current state.
On 02/14/2018 02:23 AM, Jeff Young wrote:
> Good stuff; I like most of these changes.
>
> A few issues:
>
> Show/Hide Layers Manager and Show/Hide Microwave Toolbar should be changed to checkable items (with just the show version of the text). They should also probably move down the menu so they’re in the same order as the toolbar buttons.
>
> I think I’d use “Zone Display” instead of “Zones” for the zone display options menu.
>
> User Defined Grid… should be moved from the Dimensions menu to just under Show Grid on the View menu and renamed Grid Settings....
I suppose Dimensions menu could be entirely moved to Preferences as a
submenu.
I also wonder if there is any reason to keep Icons submenu, as there is
only one entry. It is not an option that is frequently changed, so could
be safely moved to Preferences dialog.
The same applies to Languages, but perhaps there is a benefit of easy
access to the menu in case KiCad runs using a language unknown to the user.
> Instead of adding a new top-level Inspect menu, how about reorganising the Tools menu:
True, perhaps at one point when we provide too many tools we can start
splitting them into submenus.
> Read Netlist…
> Update PCB from Schematic…
> ——————
> Measure
> Design Rules Checker
> ——————
> Set Layer Pair…
> FreeRoute
>
> Alternatively, if others really like the Inspect menu, we should move Design Rules Checker to it as well.
>
> I don’t think I’d move the global editing stuff from the Edit menu to the Tools menu.
>
> Pads Mask Clearance… and Differential Pairs... should probably move to the Design Rules menu? (Or perhaps Differential Pairs… should go to the Route menu? Either way it should be renamed Differential Pair Settings….)
>
> Oh, and one of the biggest issues with Legacy vs Modern is that folks think it’s just a view change (not a whole different toolset). We should move them to the Preferences menu to help clear that up. They’d go well near Display Settings….
Then maybe we could make it sound more descriptive? How about 'Modern
toolset'?
Cheers,
Orson
> Cheers,
> Jeff
>
>
>
>> On 13 Feb 2018, at 22:46, Michael Kavanagh <michael@xxxxxxxxxxxxxxxxxx> wrote:
>>
>> <0007-Pcbnew-Add-missing-tools-to-menubar.patch>
>
>
>
>
> _______________________________________________
> Mailing list: https://launchpad.net/~kicad-developers
> Post to : kicad-developers@xxxxxxxxxxxxxxxxxxx
> Unsubscribe : https://launchpad.net/~kicad-developers
> More help : https://help.launchpad.net/ListHelp
>
From 1a044413605d2ae5daf550f2f28866d8ec8e7be4 Mon Sep 17 00:00:00 2001
From: Maciej Suminski <maciej.suminski@xxxxxxx>
Date: Wed, 14 Feb 2018 09:08:29 +0100
Subject: [PATCH] Do not set bitmaps for wxITEM_RADIO menu items on Linux and
macOS
---
common/bitmap.cpp | 19 +++++++++++--------
1 file changed, 11 insertions(+), 8 deletions(-)
diff --git a/common/bitmap.cpp b/common/bitmap.cpp
index 4a09ab49a..d1ccd1071 100644
--- a/common/bitmap.cpp
+++ b/common/bitmap.cpp
@@ -170,8 +170,9 @@ wxBitmap* KiBitmapNew( BITMAP_DEF aBitmap )
return bitmap;
}
+
wxMenuItem* AddMenuItem( wxMenu* aMenu, int aId, const wxString& aText,
- const wxBitmap& aImage, wxItemKind aType = wxITEM_NORMAL )
+ const wxBitmap& aImage, wxItemKind aType = wxITEM_NORMAL )
{
wxMenuItem* item;
@@ -182,14 +183,14 @@ wxMenuItem* AddMenuItem( wxMenu* aMenu, int aId, const wxString& aText,
if( useImagesInMenus )
{
- if( aType == wxITEM_CHECK )
+ if( aType == wxITEM_CHECK || aType == wxITEM_RADIO )
{
#if defined( __WINDOWS__ )
item->SetBitmaps( KiBitmap( checked_ok_xpm ), aImage );
// A workaround to a strange bug on Windows, wx Widgets 3.0:
// size of bitmaps is not taken in account for wxITEM_CHECK menu
// unless we call SetFont
- item->SetFont(*wxNORMAL_FONT);
+ item->SetFont( *wxNORMAL_FONT );
#endif
}
else
@@ -201,6 +202,7 @@ wxMenuItem* AddMenuItem( wxMenu* aMenu, int aId, const wxString& aText,
return item;
}
+
wxMenuItem* AddMenuItem( wxMenu* aMenu, int aId, const wxString& aText,
const wxString& aHelpText, const wxBitmap& aImage,
wxItemKind aType = wxITEM_NORMAL )
@@ -214,14 +216,14 @@ wxMenuItem* AddMenuItem( wxMenu* aMenu, int aId, const wxString& aText,
if( useImagesInMenus )
{
- if( aType == wxITEM_CHECK )
+ if( aType == wxITEM_CHECK || aType == wxITEM_RADIO )
{
#if defined( __WINDOWS__ )
item->SetBitmaps( KiBitmap( checked_ok_xpm ), aImage );
// A workaround to a strange bug on Windows, wx Widgets 3.0:
// size of bitmaps is not taken in account for wxITEM_CHECK menu
// unless we call SetFont
- item->SetFont(*wxNORMAL_FONT);
+ item->SetFont( *wxNORMAL_FONT );
#endif
}
else
@@ -233,6 +235,7 @@ wxMenuItem* AddMenuItem( wxMenu* aMenu, int aId, const wxString& aText,
return item;
}
+
wxMenuItem* AddMenuItem( wxMenu* aMenu, wxMenu* aSubMenu, int aId,
const wxString& aText, const wxBitmap& aImage )
{
@@ -255,7 +258,7 @@ wxMenuItem* AddMenuItem( wxMenu* aMenu, wxMenu* aSubMenu, int aId,
wxMenuItem* AddMenuItem( wxMenu* aMenu, wxMenu* aSubMenu, int aId,
const wxString& aText, const wxString& aHelpText,
- const wxBitmap& aImage )
+ const wxBitmap& aImage )
{
wxMenuItem* item;
@@ -182,14 +183,14 @@ wxMenuItem* AddMenuItem( wxMenu* aMenu, int aId, const wxString& aText,
item->SetBitmaps( KiBitmap( checked_ok_xpm ), aImage );
// A workaround to a strange bug on Windows, wx Widgets 3.0:
- // size of bitmaps is not taken in account for wxITEM_CHECK menu
+ // size of bitmaps is not taken in account for wxITEM_{CHECK,RADIO} menu
// unless we call SetFont
@@ -214,14 +216,14 @@ wxMenuItem* AddMenuItem( wxMenu* aMenu, int aId, const wxString& aText,
item->SetBitmaps( KiBitmap( checked_ok_xpm ), aImage );
// A workaround to a strange bug on Windows, wx Widgets 3.0:
- // size of bitmaps is not taken in account for wxITEM_CHECK menu
+ // size of bitmaps is not taken in account for wxITEM_{CHECK,RADIO} menu
// unless we call SetFont
--
2.13.3
Attachment:
signature.asc
Description: OpenPGP digital signature
Follow ups
References